/**
 *  ----------------------------------------------------------------------------
 *  Copyright (c) 2015, Anaren Microwave, Inc.
 *
 *  For more information on licensing, please see Anaren Microwave, Inc's
 *  end user software licensing agreement: EULA.txt.
 *
 *  ----------------------------------------------------------------------------
 *
 *  tmp112.c - driver interface for the Texas Instruments TMP112 Temperature Sensor.
 *  @version    1.0.01
 *  @date       26 Nov 2015
 *  @author     Anaren, air@anaren.com
 *
 *  assumptions
 *  ===========
 *  - The i2c driver provides the proper signaling sequences for read & write
 *    operations.
 *  - The i2c driver meets the timing requirements specified in the TMP112
 *    datasheet.
 *
 *  file dependency
 *  ===============
 *  i2c.h : defines the i2c read & write interfaces.
 *	math.h : floating point calculations.
 *	fp_math.h : floating point calculations using fixed point math.  Use when math.h not implemented.
 *
 *  revision history
 *  ================
 *  ver 1.0.00 : 26 Nov 2015
 *  - initial release
 */
#include "tmp112.h"

#ifdef FLOATING_POINT_AVAILABLE
#include <math.h>
#else
#include "../fp_math/fp_math.h"
#endif

// -----------------------------------------------------------------------------
/**
 *  Global data
 */

// -----------------------------------------------------------------------------
/**
 *  Public interface
 */

void TMP112_SoftwareReset(uint8 id)
{
  uint8 writeBytes[] = {TMP112_CONFIG_REG_ADDR, 0x61, 0xA0};
  AIR_I2C_Write(TMP112_SLAVE_BASE_ADDR + id, writeBytes, 3);
}


char TMP112_GetAmbientTemperature(uint8 id)
{
  uint8 writeBytes1[] = {TMP112_CONFIG_REG_ADDR, 0xE1, 0xA0};
  uint8 writeBytes2[1] = {TMP112_CONFIG_REG_ADDR};
  uint8 writeBytes3[] = {TMP112_TAMBIENT_REG_ADDR};
  uint8 readBytes[2];

  // request one-shot temperature conversion
  AIR_I2C_Write(TMP112_SLAVE_BASE_ADDR + id, writeBytes1, 3);

  do  // wait for conversion ready
  {
	AIR_I2C_Write(TMP112_SLAVE_BASE_ADDR + id, writeBytes2, 1);
    AIR_I2C_Read(TMP112_SLAVE_BASE_ADDR + id, readBytes, 2);
  } while (!(readBytes[0] & 0x80));

  // Now read the temperature
  AIR_I2C_Write(TMP112_SLAVE_BASE_ADDR + id, writeBytes3, 1);
  AIR_I2C_Read(TMP112_SLAVE_BASE_ADDR + id, readBytes, 2);

  if (readBytes[1] & 0x80)	// rounding off
    readBytes[0]++;

  return (char)readBytes[0];
}





